@@ -7,7 +7,8 @@ from langchain_core.tools import Tool
 from langchain_openai import ChatOpenAI
 
 from src.langtrace_python_sdk import langtrace
-from src.utils.with_root_span import with_langtrace_root_span
+from src.langtrace_python_sdk.utils.with_root_span import \
+    with_langtrace_root_span
 
 _ = load_dotenv(find_dotenv())
 
