@@ -2,7 +2,8 @@ from dotenv import find_dotenv, load_dotenv
 from openai import OpenAI
 
 from src.langtrace_python_sdk import langtrace
-from src.utils.with_root_span import with_langtrace_root_span
+from src.langtrace_python_sdk.utils.with_root_span import \
+    with_langtrace_root_span
 
 _ = load_dotenv(find_dotenv())
 
